@@ -15,6 +15,27 @@ def configure():
     pass
 
 
+def get_access_token(profile, client_id, client_secret_id):
+    if profile == 'dev':
+        access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+    else:
+        access_token_api = "https://login.aaic.cc/oauth2/token"
+
+    str_to_encode = client_id + ":" + client_secret_id
+    encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
+    encoded_value = encoded_str.decode('utf-8')
+    data = {'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest'}
+    access_token_api_headers = {"Authorization": f"Basic {encoded_value}",
+                                "content-type": "application/x-www-form-urlencoded"}
+    token = requests.post(access_token_api, headers=access_token_api_headers, data=data)
+    if token.status_code == 400:
+        click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
+        exit()
+    else:
+        token_data = token.json()
+
+    access_token = token_data["access_token"]
+    return access_token
 # Creating command
 @configure.command(name='configure')
 @click.option('--env', '-e', required=False)
@@ -123,30 +144,31 @@ def run(testrun_id, git_pass, wait_time, env):
         click.echo('\n"error" : "Please add your valid USER_ID, CLIENT_ID and CLIENT_SECRET_ID in configure file."\n')
         exit()
 
-    str_to_encode = client_id + ":" + client_secret_id
+    # str_to_encode = client_id + ":" + client_secret_id
 
-    encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
+    # encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
 
-    encoded_value = encoded_str.decode('utf-8')
+    # encoded_value = encoded_str.decode('utf-8')
 
-    access_token_api_headers = {"Authorization": f"Basic {encoded_value}",
-                                "content-type": "application/x-www-form-urlencoded"}
+    # access_token_api_headers = {"Authorization": f"Basic {encoded_value}",
+    #                             "content-type": "application/x-www-form-urlencoded"}
 
-    if profile == 'dev':
-        access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
-    else:
-        access_token_api = "https://login.aaic.cc/oauth2/token"
+    # if profile == 'dev':
+    #     access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+    # else:
+    #     access_token_api = "https://login.aaic.cc/oauth2/token"
 
-    data = {'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest'}
+    # data = {'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest'}
 
-    token = requests.post(access_token_api, headers=access_token_api_headers, data=data)
-    if token.status_code == 400:
-        click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
-        exit()
-    else:
-        token_data = token.json()
+    # token = requests.post(access_token_api, headers=access_token_api_headers, data=data)
+    # if token.status_code == 400:
+    #     click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
+    #     exit()
+    # else:
+    #     token_data = token.json()
 
-    access_token = token_data["access_token"]
+    # access_token = token_data["access_token"]
+    access_token = get_access_token(profile, client_id, client_secret_id)
 
     headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier": user_id}
 
@@ -191,6 +213,9 @@ def run(testrun_id, git_pass, wait_time, env):
             click.echo("Testrun is in progress, result will be displayed once it get completed.")
             new_time = datetime.now() + timedelta(minutes=int(wait_time))
             test_status = ""
+            # get access token for every status call to avoid token expiration
+            access_token = get_access_token(profile=profile, client_id=client_id, client_secret_id=client_secret_id)
+            headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier": user_id}
             while test_status != "completed":
                 if (new_time.strftime("%H:%M:%S")) <= (datetime.now().strftime("%H:%M:%S")):
                     click.echo(
@@ -272,30 +297,31 @@ def status(testrun_id, env):
         click.echo('\n"error" : "Please add your valid USER_ID, CLIENT_ID and CLIENT_SECRET_ID in configure file."\n')
         exit()
 
-    str_to_encode = client_id + ":" + client_secret_id
+    # str_to_encode = client_id + ":" + client_secret_id
 
-    encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
+    # encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
 
-    encoded_value = encoded_str.decode('utf-8')
+    # encoded_value = encoded_str.decode('utf-8')
 
-    access_token_api_headers = {"Authorization": f"Basic {encoded_value}",
-                                "content-type": "application/x-www-form-urlencoded"}
+    # access_token_api_headers = {"Authorization": f"Basic {encoded_value}",
+    #                             "content-type": "application/x-www-form-urlencoded"}
 
-    if profile == 'dev':
-        access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
-    else:
-        access_token_api = "https://login.aaic.cc/oauth2/token"
+    # if profile == 'dev':
+    #     access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+    # else:
+    #     access_token_api = "https://login.aaic.cc/oauth2/token"
 
-    data = {'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest'}
+    # data = {'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest'}
 
-    token = requests.post(access_token_api, headers=access_token_api_headers, data=data)
-    if token.status_code == 400:
-        click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
-        exit()
-    else:
-        token_data = token.json()
+    # token = requests.post(access_token_api, headers=access_token_api_headers, data=data)
+    # if token.status_code == 400:
+    #     click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
+    #     exit()
+    # else:
+    #     token_data = token.json()
 
-    access_token = token_data["access_token"]
+    # access_token = token_data["access_token"]
+    access_token = get_access_token(profile=profile, client_id=client_id, client_secret_id=client_secret_id)
 
     headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier": user_id}
     if profile == 'dev':
